@@ -25,21 +25,26 @@ import (
 
 func TestMockKnDynamicClient(t *testing.T) {
 
-	client := NewMockKnDyanmicClient(t)
+	client := NewMockKnDynamicClient(t)
 
 	recorder := client.Recorder()
 
 	recorder.ListCRDs(mock.Any(), nil, nil)
 	recorder.ListSourcesTypes(nil, nil)
 	recorder.ListSources(mock.Any(), nil, nil)
+	recorder.ListChannelsTypes(nil, nil)
 	recorder.RawClient(&fake.FakeDynamicClient{})
 	recorder.ListSourcesUsingGVKs(mock.Any(), mock.Any(), nil, nil)
+	recorder.ListChannelsUsingGVKs(mock.Any(), mock.Any(), nil, nil)
 
 	client.ListCRDs(metav1.ListOptions{})
 	client.ListSourcesTypes()
+	client.ListChannelsTypes()
 	client.ListSources(WithTypeFilter("blub"))
 	client.RawClient()
 	client.ListSourcesUsingGVKs(&[]schema.GroupVersionKind{}, WithTypeFilter("blub"))
+	client.ListChannelsUsingGVKs(&[]schema.GroupVersionKind{}, WithTypeFilter("blub"))
+
 	// Validate
 	recorder.Validate()
 }
