@@ -15,54 +15,44 @@
 package service
 
 import (
-	"errors"
 	"fmt"
+	"strconv"
 	"strings"
 
 	"github.com/spf13/cobra"
 
-	corev1 "k8s.io/api/core/v1"
-	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
 	knflags "knative.dev/client/pkg/kn/flags"
 	servinglib "knative.dev/client/pkg/serving"
 	"knative.dev/client/pkg/util"
+	network "knative.dev/networking/pkg"
+	"knative.dev/serving/pkg/apis/autoscaling"
 	"knative.dev/serving/pkg/apis/serving"
 	servingv1 "knative.dev/serving/pkg/apis/serving/v1"
 )
 
 type ConfigurationEditFlags struct {
+	//Fields for PodSpecFlags
+	PodSpecFlags knflags.PodSpecFlags
+
 	// Direct field manipulation
-	Image   uniqueStringArg
-	Env     []string
-	EnvFrom []string
-	Mount   []string
-	Volume  []string
-
-	Command string
-	Arg     []string
-
-	RequestsFlags, LimitsFlags ResourceFlags // TODO: Flag marked deprecated in release v0.15.0, remove in release v0.18.0
-	Resources                  knflags.ResourceOptions
-	Scale                      int
-	MinScale                   int
-	MaxScale                   int
-	ConcurrencyTarget          int
-	ConcurrencyLimit           int
-	ConcurrencyUtilization     int
-	AutoscaleWindow            string
-	Port                       string
-	Labels                     []string
-	LabelsService              []string
-	LabelsRevision             []string
-	NamePrefix                 string
-	RevisionName               string
-	ServiceAccountName         string
-	ImagePullSecrets           string
-	Annotations                []string
-	ClusterLocal               bool
-	User                       int64
+	Scale                  string
+	MinScale               int
+	MaxScale               int
+	ConcurrencyTarget      int
+	ConcurrencyLimit       int
+	ConcurrencyUtilization int
+	AutoscaleWindow        string
+	Labels                 []string
+	LabelsService          []string
+	LabelsRevision         []string
+	RevisionName           string
+	Annotations            []string
+	AnnotationsService     []string
+	AnnotationsRevision    []string
+	ClusterLocal           bool
+	ScaleInit              int
 
 	// Preferences about how to do the action.
 	LockToDigest         bool
@@ -75,30 +65,6 @@ type ConfigurationEditFlags struct {
 	flags []string
 }
 
-type ResourceFlags struct {
-	CPU    string
-	Memory string
-}
-
-// -- uniqueStringArg Value
-// Custom implementation of flag.Value interface to prevent multiple value assignment.
-// Useful to enforce unique use of flags, e.g. --image.
-type uniqueStringArg string
-
-func (s *uniqueStringArg) Set(val string) error {
-	if len(*s) > 0 {
-		return errors.New("can be provided only once")
-	}
-	*s = uniqueStringArg(val)
-	return nil
-}
-
-func (s *uniqueStringArg) Type() string {
-	return "string"
-}
-
-func (s *uniqueStringArg) String() string { return string(*s) }
-
 // markFlagMakesRevision indicates that a flag will create a new revision if you
 // set it.
 func (p *ConfigurationEditFlags) markFlagMakesRevision(f string) {
@@ -107,90 +73,32 @@ func (p *ConfigurationEditFlags) markFlagMakesRevision(f string) {
 
 // addSharedFlags adds the flags common between create & update.
 func (p *ConfigurationEditFlags) addSharedFlags(command *cobra.Command) {
-	command.Flags().VarP(&p.Image, "image", "", "Image to run.")
-	p.markFlagMakesRevision("image")
-	command.Flags().StringArrayVarP(&p.Env, "env", "e", []string{},
-		"Environment variable to set. NAME=value; you may provide this flag "+
-			"any number of times to set multiple environment variables. "+
-			"To unset, specify the environment variable name followed by a \"-\" (e.g., NAME-).")
-	p.markFlagMakesRevision("env")
-
-	command.Flags().StringArrayVarP(&p.EnvFrom, "env-from", "", []string{},
-		"Add environment variables from a ConfigMap (prefix cm: or config-map:) or a Secret (prefix secret:). "+
-			"Example: --env-from cm:myconfigmap or --env-from secret:mysecret. "+
-			"You can use this flag multiple times. "+
-			"To unset a ConfigMap/Secret reference, append \"-\" to the name, e.g. --env-from cm:myconfigmap-.")
-	p.markFlagMakesRevision("env-from")
-
-	command.Flags().StringArrayVarP(&p.Mount, "mount", "", []string{},
-		"Mount a ConfigMap (prefix cm: or config-map:), a Secret (prefix secret: or sc:), or an existing Volume (without any prefix) on the specified directory. "+
-			"Example: --mount /mydir=cm:myconfigmap, --mount /mydir=secret:mysecret, or --mount /mydir=myvolume. "+
-			"When a configmap or a secret is specified, a corresponding volume is automatically generated. "+
-			"You can use this flag multiple times. "+
-			"For unmounting a directory, append \"-\", e.g. --mount /mydir-, which also removes any auto-generated volume.")
-	p.markFlagMakesRevision("mount")
-
-	command.Flags().StringArrayVarP(&p.Volume, "volume", "", []string{},
-		"Add a volume from a ConfigMap (prefix cm: or config-map:) or a Secret (prefix secret: or sc:). "+
-			"Example: --volume myvolume=cm:myconfigmap or --volume myvolume=secret:mysecret. "+
-			"You can use this flag multiple times. "+
-			"To unset a ConfigMap/Secret reference, append \"-\" to the name, e.g. --volume myvolume-.")
-	p.markFlagMakesRevision("volume")
-
-	command.Flags().StringVarP(&p.Command, "cmd", "", "",
-		"Specify command to be used as entrypoint instead of default one. "+
-			"Example: --cmd /app/start or --cmd /app/start --arg myArg to pass aditional arguments.")
-	p.markFlagMakesRevision("cmd")
-
-	command.Flags().StringArrayVarP(&p.Arg, "arg", "", []string{},
-		"Add argument to the container command. "+
-			"Example: --arg myArg1 --arg --myArg2 --arg myArg3=3. "+
-			"You can use this flag multiple times.")
-	p.markFlagMakesRevision("arg")
-
-	command.Flags().StringSliceVar(&p.Resources.Limits,
-		"limit",
-		nil,
-		"The resource requirement limits for this Service. For example, 'cpu=100m,memory=256Mi'. "+
-			"You can use this flag multiple times. "+
-			"To unset a resource limit, append \"-\" to the resource name, e.g. '--limit memory-'.")
-	p.markFlagMakesRevision("limit")
-
-	command.Flags().StringSliceVar(&p.Resources.Requests,
-		"request",
-		nil,
-		"The resource requirement requests for this Service. For example, 'cpu=100m,memory=256Mi'. "+
-			"You can use this flag multiple times. "+
-			"To unset a resource request, append \"-\" to the resource name, e.g. '--request cpu-'.")
-	p.markFlagMakesRevision("request")
-
-	command.Flags().StringVar(&p.RequestsFlags.CPU, "requests-cpu", "",
-		"DEPRECATED: please use --request instead. The requested CPU (e.g., 250m).")
-	p.markFlagMakesRevision("requests-cpu")
-
-	command.Flags().StringVar(&p.RequestsFlags.Memory, "requests-memory", "",
-		"DEPRECATED: please use --request instead. The requested memory (e.g., 64Mi).")
-	p.markFlagMakesRevision("requests-memory")
-
-	// TODO: Flag marked deprecated in release v0.15.0, remove in release v0.18.0
-	command.Flags().StringVar(&p.LimitsFlags.CPU, "limits-cpu", "",
-		"DEPRECATED: please use --limit instead. The limits on the requested CPU (e.g., 1000m).")
-	p.markFlagMakesRevision("limits-cpu")
-
-	// TODO: Flag marked deprecated in release v0.15.0, remove in release v0.18.0
-	command.Flags().StringVar(&p.LimitsFlags.Memory, "limits-memory", "",
-		"DEPRECATED: please use --limit instead. The limits on the requested memory (e.g., 1024Mi).")
-	p.markFlagMakesRevision("limits-memory")
+	flagNames := p.PodSpecFlags.AddFlags(command.Flags())
+	for _, name := range flagNames {
+		p.markFlagMakesRevision(name)
+	}
 
 	command.Flags().IntVar(&p.MinScale, "min-scale", 0, "Minimal number of replicas.")
+	command.Flags().MarkHidden("min-scale")
 	p.markFlagMakesRevision("min-scale")
 
 	command.Flags().IntVar(&p.MaxScale, "max-scale", 0, "Maximal number of replicas.")
+	command.Flags().MarkHidden("max-scale")
 	p.markFlagMakesRevision("max-scale")
 
-	command.Flags().IntVar(&p.Scale, "scale", 0, "Minimum and maximum number of replicas.")
+	command.Flags().StringVar(&p.Scale, "scale", "",
+		"Set the Minimum and Maximum number of replicas. You can use this flag to set both to a single value, "+
+			"or set a range with min/max values, or set either min or max values without specifying the other. "+
+			"Example: --scale 5 (scale-min = 5, scale-max = 5) or --scale 1..5 (scale-min = 1, scale-max = 5) or --scale "+
+			"1.. (scale-min = 1, scale-max = unchanged) or --scale ..5 (scale-min = unchanged, scale-max = 5)")
 	p.markFlagMakesRevision("scale")
 
+	command.Flags().IntVar(&p.MinScale, "scale-min", 0, "Minimum number of replicas.")
+	p.markFlagMakesRevision("scale-min")
+
+	command.Flags().IntVar(&p.MaxScale, "scale-max", 0, "Maximum number of replicas.")
+	p.markFlagMakesRevision("scale-max")
+
 	command.Flags().StringVar(&p.AutoscaleWindow, "autoscale-window", "", "Duration to look back for making auto-scaling decisions. The service is scaled to zero if no request was received in during that time. (eg: 10s)")
 	p.markFlagMakesRevision("autoscale-window")
 
@@ -213,9 +121,6 @@ func (p *ConfigurationEditFlags) addSharedFlags(command *cobra.Command) {
 		"Percentage of concurrent requests utilization before scaling up.")
 	p.markFlagMakesRevision("concurrency-utilization")
 
-	command.Flags().StringVarP(&p.Port, "port", "p", "", "The port where application listens on, in the format 'NAME:PORT', where 'NAME' is optional. Examples: '--port h2c:8080' , '--port 8080'.")
-	p.markFlagMakesRevision("port")
-
 	command.Flags().StringArrayVarP(&p.Labels, "label", "l", []string{},
 		"Labels to set for both Service and Revision. name=value; you may provide this flag "+
 			"any number of times to set multiple labels. "+
@@ -226,13 +131,13 @@ func (p *ConfigurationEditFlags) addSharedFlags(command *cobra.Command) {
 		"Service label to set. name=value; you may provide this flag "+
 			"any number of times to set multiple labels. "+
 			"To unset, specify the label name followed by a \"-\" (e.g., name-). This flag takes "+
-			"precedence over \"label\" flag.")
+			"precedence over the \"label\" flag.")
 	p.markFlagMakesRevision("label-service")
 	command.Flags().StringArrayVarP(&p.LabelsRevision, "label-revision", "", []string{},
 		"Revision label to set. name=value; you may provide this flag "+
 			"any number of times to set multiple labels. "+
 			"To unset, specify the label name followed by a \"-\" (e.g., name-). This flag takes "+
-			"precedence over \"label\" flag.")
+			"precedence over the \"label\" flag.")
 	p.markFlagMakesRevision("label-revision")
 
 	command.Flags().StringVar(&p.RevisionName, "revision-name", "{{.Service}}-{{.Random 5}}-{{.Generation}}",
@@ -247,25 +152,28 @@ func (p *ConfigurationEditFlags) addSharedFlags(command *cobra.Command) {
 			"the image. (--no-lock-to-digest pulls the image tag afresh with each new revision)")
 	// Don't mark as changing the revision.
 
-	command.Flags().StringVar(&p.ServiceAccountName,
-		"service-account",
-		"",
-		"Service account name to set. An empty argument (\"\") clears the service account. The referenced service account must exist in the service's namespace.")
-	p.markFlagMakesRevision("service-account")
-
 	command.Flags().StringArrayVarP(&p.Annotations, "annotation", "a", []string{},
-		"Service annotation to set. name=value; you may provide this flag "+
+		"Annotations to set for both Service and Revision. name=value; you may provide this flag "+
 			"any number of times to set multiple annotations. "+
 			"To unset, specify the annotation name followed by a \"-\" (e.g., name-).")
 	p.markFlagMakesRevision("annotation")
 
-	command.Flags().StringVar(&p.ImagePullSecrets,
-		"pull-secret",
-		"",
-		"Image pull secret to set. An empty argument (\"\") clears the pull secret. The referenced secret must exist in the service's namespace.")
-	p.markFlagMakesRevision("pull-secret")
-	command.Flags().Int64VarP(&p.User, "user", "", 0, "The user ID to run the container (e.g., 1001).")
-	p.markFlagMakesRevision("user")
+	command.Flags().StringArrayVarP(&p.AnnotationsService, "annotation-service", "", []string{},
+		"Service annotation to set. name=value; you may provide this flag "+
+			"any number of times to set multiple annotations. "+
+			"To unset, specify the annotation name followed by a \"-\" (e.g., name-). This flag takes "+
+			"precedence over the \"annotation\" flag.")
+	p.markFlagMakesRevision("annotation-service")
+
+	command.Flags().StringArrayVarP(&p.AnnotationsRevision, "annotation-revision", "", []string{},
+		"Revision annotation to set. name=value; you may provide this flag "+
+			"any number of times to set multiple annotations. "+
+			"To unset, specify the annotation name followed by a \"-\" (e.g., name-). This flag takes "+
+			"precedence over the \"annotation\" flag.")
+	p.markFlagMakesRevision("annotation-revision")
+
+	command.Flags().IntVar(&p.ScaleInit, "scale-init", 0, "Initial number of replicas with which a service starts. Can be 0 or a positive integer.")
+	p.markFlagMakesRevision("scale-init")
 }
 
 // AddUpdateFlags adds the flags specific to update.
@@ -278,8 +186,11 @@ func (p *ConfigurationEditFlags) AddCreateFlags(command *cobra.Command) {
 	p.addSharedFlags(command)
 	command.Flags().BoolVar(&p.ForceCreate, "force", false,
 		"Create service forcefully, replaces existing service if any.")
-	command.Flags().StringVarP(&p.Filename, "filename", "f", "", "Create a service from file.")
+	command.Flags().StringVarP(&p.Filename, "filename", "f", "", "Create a service from file. "+
+		"The created service can be further modified by combining with other options. "+
+		"For example, -f /path/to/file --env NAME=value adds also an environment variable.")
 	command.MarkFlagFilename("filename")
+	p.markFlagMakesRevision("filename")
 }
 
 // Apply mutates the given service according to the flags in the command.
@@ -289,53 +200,10 @@ func (p *ConfigurationEditFlags) Apply(
 	cmd *cobra.Command) error {
 
 	template := &service.Spec.Template
-	if cmd.Flags().Changed("env") {
-		envMap, err := util.MapFromArrayAllowingSingles(p.Env, "=")
-		if err != nil {
-			return fmt.Errorf("Invalid --env: %w", err)
-		}
 
-		envToRemove := util.ParseMinusSuffix(envMap)
-		err = servinglib.UpdateEnvVars(template, envMap, envToRemove)
-		if err != nil {
-			return err
-		}
-	}
-
-	if cmd.Flags().Changed("env-from") {
-		envFromSourceToUpdate := []string{}
-		envFromSourceToRemove := []string{}
-		for _, name := range p.EnvFrom {
-			if name == "-" {
-				return fmt.Errorf("\"-\" is not a valid value for \"--env-from\"")
-			} else if strings.HasSuffix(name, "-") {
-				envFromSourceToRemove = append(envFromSourceToRemove, name[:len(name)-1])
-			} else {
-				envFromSourceToUpdate = append(envFromSourceToUpdate, name)
-			}
-		}
-
-		err := servinglib.UpdateEnvFrom(template, envFromSourceToUpdate, envFromSourceToRemove)
-		if err != nil {
-			return err
-		}
-	}
-
-	if cmd.Flags().Changed("mount") || cmd.Flags().Changed("volume") {
-		mountsToUpdate, mountsToRemove, err := util.OrderedMapAndRemovalListFromArray(p.Mount, "=")
-		if err != nil {
-			return fmt.Errorf("Invalid --mount: %w", err)
-		}
-
-		volumesToUpdate, volumesToRemove, err := util.OrderedMapAndRemovalListFromArray(p.Volume, "=")
-		if err != nil {
-			return fmt.Errorf("Invalid --volume: %w", err)
-		}
-
-		err = servinglib.UpdateVolumeMountsAndVolumes(template, mountsToUpdate, mountsToRemove, volumesToUpdate, volumesToRemove)
-		if err != nil {
-			return err
-		}
+	err := p.PodSpecFlags.ResolvePodSpec(&template.Spec.PodSpec, cmd.Flags())
+	if err != nil {
+		return err
 	}
 
 	name, err := servinglib.GenerateRevisionName(p.RevisionName, service)
@@ -349,10 +217,6 @@ func (p *ConfigurationEditFlags) Apply(
 
 	imageSet := false
 	if cmd.Flags().Changed("image") {
-		err = servinglib.UpdateImage(template, p.Image.String())
-		if err != nil {
-			return err
-		}
 		imageSet = true
 	}
 	_, userImagePresent := template.Annotations[servinglib.UserImageAnnotationKey]
@@ -383,58 +247,16 @@ func (p *ConfigurationEditFlags) Apply(
 		fmt.Fprintf(cmd.OutOrStdout(), "\nWARNING: flags --requests-cpu / --requests-memory are deprecated and going to be removed in future release, please use --request instead.\n\n")
 	}
 
-	limitsResources, err := p.computeResources(p.LimitsFlags)
-	if err != nil {
-		return err
-	}
-	requestsResources, err := p.computeResources(p.RequestsFlags)
-	if err != nil {
-		return err
-	}
-	err = servinglib.UpdateResourcesDeprecated(template, requestsResources, limitsResources)
-	if err != nil {
-		return err
-	}
-
-	requestsToRemove, limitsToRemove, err := p.Resources.Validate()
-	if err != nil {
-		return err
-	}
-
-	err = servinglib.UpdateResources(template, p.Resources.ResourceRequirements, requestsToRemove, limitsToRemove)
-	if err != nil {
-		return err
-	}
-
-	if cmd.Flags().Changed("cmd") {
-		err = servinglib.UpdateContainerCommand(template, p.Command)
-		if err != nil {
-			return err
-		}
-	}
-
-	if cmd.Flags().Changed("arg") {
-		err = servinglib.UpdateContainerArg(template, p.Arg)
-		if err != nil {
-			return err
-		}
-	}
-
-	if cmd.Flags().Changed("port") {
-		err = servinglib.UpdateContainerPort(template, p.Port)
-		if err != nil {
-			return err
-		}
-	}
-
-	if cmd.Flags().Changed("min-scale") {
+	// Deprecated "min-scale" in 0.19, updated to "scale-min"
+	if cmd.Flags().Changed("scale-min") || cmd.Flags().Changed("min-scale") {
 		err = servinglib.UpdateMinScale(template, p.MinScale)
 		if err != nil {
 			return err
 		}
 	}
 
-	if cmd.Flags().Changed("max-scale") {
+	// Deprecated "max-scale" in 0.19, updated to "scale-max"
+	if cmd.Flags().Changed("scale-max") || cmd.Flags().Changed("max-scale") {
 		err = servinglib.UpdateMaxScale(template, p.MaxScale)
 		if err != nil {
 			return err
@@ -442,19 +264,45 @@ func (p *ConfigurationEditFlags) Apply(
 	}
 
 	if cmd.Flags().Changed("scale") {
-		if cmd.Flags().Changed("max-scale") {
-			return fmt.Errorf("only --scale or --max-scale can be specified")
-		} else if cmd.Flags().Changed("min-scale") {
-			return fmt.Errorf("only --scale or --min-scale can be specified")
+		if cmd.Flags().Changed("scale-max") {
+			return fmt.Errorf("only --scale or --scale-max can be specified")
+		} else if cmd.Flags().Changed("scale-min") {
+			return fmt.Errorf("only --scale or --scale-min can be specified")
+		}
+		if strings.Contains(p.Scale, "..") {
+			scaleParts := strings.Split(p.Scale, "..")
+			if scaleParts[0] != "" {
+				scaleMin, err := strconv.Atoi(scaleParts[0])
+				if err != nil {
+					return err
+				}
+				err = servinglib.UpdateMinScale(template, scaleMin)
+				if err != nil {
+					return err
+				}
+			}
+			if scaleParts[1] != "" {
+				scaleMax, err := strconv.Atoi(scaleParts[1])
+				if err != nil {
+					return err
+				}
+				err = servinglib.UpdateMaxScale(template, scaleMax)
+				if err != nil {
+					return err
+				}
+			}
+		} else if scaleMin, err := strconv.Atoi(p.Scale); err == nil {
+			scaleMax := scaleMin
+			err = servinglib.UpdateMaxScale(template, scaleMax)
+			if err != nil {
+				return err
+			}
+			err = servinglib.UpdateMinScale(template, scaleMin)
+			if err != nil {
+				return err
+			}
 		} else {
-			err = servinglib.UpdateMaxScale(template, p.Scale)
-			if err != nil {
-				return err
-			}
-			err = servinglib.UpdateMinScale(template, p.Scale)
-			if err != nil {
-				return err
-			}
+			return fmt.Errorf("Scale must be of the format x..y or x")
 		}
 	}
 
@@ -488,10 +336,10 @@ func (p *ConfigurationEditFlags) Apply(
 
 	if cmd.Flags().Changed("cluster-local") || cmd.Flags().Changed("no-cluster-local") {
 		if p.ClusterLocal {
-			labels := servinglib.UpdateLabels(service.ObjectMeta.Labels, map[string]string{serving.VisibilityLabelKey: serving.VisibilityClusterLocal}, []string{})
+			labels := servinglib.UpdateLabels(service.ObjectMeta.Labels, map[string]string{network.VisibilityLabelKey: serving.VisibilityClusterLocal}, []string{})
 			service.ObjectMeta.Labels = labels // In case service.ObjectMeta.Labels was nil
 		} else {
-			labels := servinglib.UpdateLabels(service.ObjectMeta.Labels, map[string]string{}, []string{serving.VisibilityLabelKey})
+			labels := servinglib.UpdateLabels(service.ObjectMeta.Labels, map[string]string{}, []string{network.VisibilityLabelKey})
 			service.ObjectMeta.Labels = labels // In case service.ObjectMeta.Labels was nil
 		}
 	}
@@ -513,32 +361,72 @@ func (p *ConfigurationEditFlags) Apply(
 		}
 	}
 
-	if cmd.Flags().Changed("annotation") {
-		annotationsMap, err := util.MapFromArrayAllowingSingles(p.Annotations, "=")
+	if cmd.Flags().Changed("annotation") || cmd.Flags().Changed("annotation-service") || cmd.Flags().Changed("annotation-revision") {
+		annotationsAllMap, err := util.MapFromArrayAllowingSingles(p.Annotations, "=")
 		if err != nil {
 			return fmt.Errorf("Invalid --annotation: %w", err)
 		}
+		annotationRevisionFlagMap, err := util.MapFromArrayAllowingSingles(p.AnnotationsRevision, "=")
+		if err != nil {
+			return fmt.Errorf("Invalid --annotation-revision: %w", err)
+		}
+		annotationServiceFlagMap, err := util.MapFromArrayAllowingSingles(p.AnnotationsService, "=")
+		if err != nil {
+			return fmt.Errorf("Invalid --annotation-service: %w", err)
+		}
 
-		annotationsToRemove := util.ParseMinusSuffix(annotationsMap)
-		err = servinglib.UpdateAnnotations(service, template, annotationsMap, annotationsToRemove)
+		annotationsToRemove := util.ParseMinusSuffix(annotationsAllMap)
+
+		revisionAnnotations := make(util.StringMap)
+		revisionAnnotations.Merge(annotationsAllMap)
+		revisionAnnotations.Merge(annotationRevisionFlagMap)
+		err = servinglib.UpdateRevisionTemplateAnnotations(template, revisionAnnotations, annotationsToRemove)
 		if err != nil {
 			return err
 		}
-	}
 
-	if cmd.Flags().Changed("service-account") {
-		err = servinglib.UpdateServiceAccountName(template, p.ServiceAccountName)
+		serviceAnnotations := make(util.StringMap)
+
+		// Service Annotations can't contain Autoscaling ones
+
+		for key, value := range annotationsAllMap {
+			if !strings.HasPrefix(key, autoscaling.GroupName) {
+				serviceAnnotations[key] = value
+			}
+		}
+
+		for key, value := range annotationServiceFlagMap {
+			if strings.HasPrefix(key, autoscaling.GroupName) {
+				return fmt.Errorf("service can not have auto-scaling related annotation: %s , please update using '--annotation-revision'", key)
+			}
+			serviceAnnotations[key] = value
+		}
+
+		err = servinglib.UpdateServiceAnnotations(service, serviceAnnotations, annotationsToRemove)
 		if err != nil {
 			return err
 		}
+
 	}
 
-	if cmd.Flags().Changed("pull-secret") {
-		servinglib.UpdateImagePullSecrets(template, p.ImagePullSecrets)
-	}
+	if cmd.Flags().Changed("scale-init") {
+		containsAnnotation := func(annotationList []string, annotation string) bool {
+			for _, element := range annotationList {
+				if strings.Contains(element, annotation) {
+					return true
+				}
+			}
+			return false
+		}
 
-	if cmd.Flags().Changed("user") {
-		servinglib.UpdateUser(template, p.User)
+		if cmd.Flags().Changed("annotation") && containsAnnotation(p.Annotations, autoscaling.InitialScaleAnnotationKey) {
+			return fmt.Errorf("only one of the --scale-init or --annotation %s can be specified", autoscaling.InitialScaleAnnotationKey)
+		}
+		// Autoscaling annotations are only applicable on Revision Template, not Service
+		err = servinglib.UpdateRevisionTemplateAnnotation(template, autoscaling.InitialScaleAnnotationKey, strconv.Itoa(p.ScaleInit))
+		if err != nil {
+			return err
+		}
 	}
 
 	return nil
@@ -558,32 +446,6 @@ func (p *ConfigurationEditFlags) updateLabels(obj *metav1.ObjectMeta, flagLabels
 	return nil
 }
 
-func (p *ConfigurationEditFlags) computeResources(resourceFlags ResourceFlags) (corev1.ResourceList, error) {
-	resourceList := corev1.ResourceList{}
-
-	if resourceFlags.CPU != "" {
-		cpuQuantity, err := resource.ParseQuantity(resourceFlags.CPU)
-		if err != nil {
-			return corev1.ResourceList{},
-				fmt.Errorf("Error parsing %q: %w", resourceFlags.CPU, err)
-		}
-
-		resourceList[corev1.ResourceCPU] = cpuQuantity
-	}
-
-	if resourceFlags.Memory != "" {
-		memoryQuantity, err := resource.ParseQuantity(resourceFlags.Memory)
-		if err != nil {
-			return corev1.ResourceList{},
-				fmt.Errorf("Error parsing %q: %w", resourceFlags.Memory, err)
-		}
-
-		resourceList[corev1.ResourceMemory] = memoryQuantity
-	}
-
-	return resourceList, nil
-}
-
 // AnyMutation returns true if there are any revision template mutations in the
 // command.
 func (p *ConfigurationEditFlags) AnyMutation(cmd *cobra.Command) bool {
