@@ -34,7 +34,7 @@ const (
 func NewServiceCommand(p *commands.KnParams) *cobra.Command {
 	serviceCmd := &cobra.Command{
 		Use:     "service",
-		Short:   "Manage Knative services (aliases: ksvc, services)",
+		Short:   "Manage Knative services",
 		Aliases: []string{"ksvc", "services"},
 	}
 	serviceCmd.AddCommand(NewServiceListCommand(p))
@@ -42,7 +42,9 @@ func NewServiceCommand(p *commands.KnParams) *cobra.Command {
 	serviceCmd.AddCommand(NewServiceCreateCommand(p))
 	serviceCmd.AddCommand(NewServiceDeleteCommand(p))
 	serviceCmd.AddCommand(NewServiceUpdateCommand(p))
+	serviceCmd.AddCommand(NewServiceApplyCommand(p))
 	serviceCmd.AddCommand(NewServiceExportCommand(p))
+	serviceCmd.AddCommand(NewServiceImportCommand(p))
 	return serviceCmd
 }
 
@@ -64,7 +66,7 @@ func showUrl(client clientservingv1.KnServingClient, serviceName string, origina
 	url := service.Status.URL.String()
 
 	newRevision := service.Status.LatestReadyRevisionName
-	if originalRevision != "" && originalRevision == newRevision {
+	if (originalRevision != "" && originalRevision == newRevision) || originalRevision == "unchanged" {
 		fmt.Fprintf(out, "Service '%s' with latest revision '%s' (unchanged) is available at URL:\n%s\n", serviceName, newRevision, url)
 	} else {
 		fmt.Fprintf(out, "Service '%s' %s to latest revision '%s' is available at URL:\n%s\n", serviceName, what, newRevision, url)
@@ -72,3 +74,10 @@ func showUrl(client clientservingv1.KnServingClient, serviceName string, origina
 
 	return nil
 }
+
+func newServingClient(p *commands.KnParams, namespace, dir string) (clientservingv1.KnServingClient, error) {
+	if dir != "" {
+		return p.NewGitopsServingClient(namespace, dir)
+	}
+	return p.NewServingClient(namespace)
+}
