@@ -25,6 +25,8 @@ import (
 	"strings"
 	"testing"
 
+	"knative.dev/serving/pkg/apis/autoscaling"
+
 	"gotest.tools/assert"
 
 	"knative.dev/client/lib/test"
@@ -118,6 +120,7 @@ func TestServiceOptions(t *testing.T) {
 	validateContainerField(r, "svc5", "args", "[myArg1 --myArg2]")
 	test.ServiceUpdate(r, "svc5", "--arg", "myArg1")
 	validateContainerField(r, "svc5", "args", "[myArg1]")
+	test.ServiceDelete(r, "svc5")
 
 	t.Log("create, update and validate service with user defined")
 	var uid int64 = 1000
@@ -130,24 +133,73 @@ func TestServiceOptions(t *testing.T) {
 	validateUserID(r, "svc6", uid)
 	test.ServiceUpdate(r, "svc6", "--user", strconv.FormatInt(uid+1, 10))
 	validateUserID(r, "svc6", uid+1)
+	test.ServiceDelete(r, "svc6")
 
 	t.Log("create and validate service and revision labels")
 	serviceCreateWithOptions(r, "svc7", "--label-service", "svc=helloworld-svc", "--label-revision", "rev=helloworld-rev")
 	validateLabels(r, "svc7", map[string]string{"svc": "helloworld-svc"}, map[string]string{"rev": "helloworld-rev"})
+	test.ServiceDelete(r, "svc7")
 
 	t.Log("create and validate service resource options")
 	serviceCreateWithOptions(r, "svc8", "--limit", "memory=500Mi,cpu=1000m", "--request", "memory=250Mi,cpu=200m")
 	test.ValidateServiceResources(r, "svc8", "250Mi", "200m", "500Mi", "1000m")
+	test.ServiceDelete(r, "svc8")
+
+	t.Log("create a grpc service and validate port name")
+	serviceCreateWithOptions(r, "svc9", "--image", pkgtest.ImagePath("grpc-ping"), "--port", "h2c:8080")
+	validatePort(r, "svc9", 8080, "h2c")
+	test.ServiceDelete(r, "svc9")
+
+	t.Log("create and validate service with scale init option")
+	serviceCreateWithOptions(r, "svc10", "--scale-init", "1")
+	validateServiceInitScale(r, "svc10", "1")
+	test.ServiceUpdate(r, "svc10", "--scale-init", "2")
+	validateServiceInitScale(r, "svc10", "2")
+	t.Log("delete service")
+	test.ServiceDelete(r, "svc10")
+
+	t.Log("create and validate service with scale init option via --annotation flag")
+	serviceCreateWithOptions(r, "svc11", "--annotation", autoscaling.InitialScaleAnnotationKey+"=2")
+	validateServiceInitScale(r, "svc11", "2")
+	t.Log("delete service")
+	test.ServiceDelete(r, "svc11")
+
+	t.Log("create and validate service and revision annotations")
+	serviceCreateWithOptions(r, "svc12", "--annotation-service", "svc=helloworld-svc", "--annotation-revision", "rev=helloworld-rev")
+	validateServiceAndRevisionAnnotations(r, "svc12", map[string]string{"svc": "helloworld-svc"}, map[string]string{"rev": "helloworld-rev"})
+	test.ServiceDelete(r, "svc12")
+
+	t.Log("create and validate service annotations")
+	serviceCreateWithOptions(r, "svc13", "--annotation-service", "svc=helloworld-svc")
+	validateServiceAndRevisionAnnotations(r, "svc13", map[string]string{"svc": "helloworld-svc"}, nil)
+	test.ServiceDelete(r, "svc13")
+
+	t.Log("create and validate revision annotations")
+	serviceCreateWithOptions(r, "svc14", "--annotation-revision", "rev=helloworld-rev")
+	validateServiceAndRevisionAnnotations(r, "svc14", nil, map[string]string{"rev": "helloworld-rev"})
+	test.ServiceDelete(r, "svc14")
 }
 
 func serviceCreateWithOptions(r *test.KnRunResultCollector, serviceName string, options ...string) {
-	command := []string{"service", "create", serviceName, "--image", pkgtest.ImagePath("helloworld")}
-	command = append(command, options...)
+	command := []string{"service", "create", serviceName}
+	command = append(command, getOptionsWithImage(options...)...)
 	out := r.KnTest().Kn().Run(command...)
 	assert.Check(r.T(), util.ContainsAll(out.Stdout, "service", serviceName, "Creating", "namespace", r.KnTest().Kn().Namespace(), "Ready"))
 	r.AssertNoError(out)
 }
 
+func getOptionsWithImage(options ...string) []string {
+	for _, o := range options {
+		if strings.HasPrefix(o, "--image") {
+			//options have an image return options
+			return options
+		}
+	}
+	//options dont have a image , add HW image
+	options = append(options, "--image="+pkgtest.ImagePath("helloworld"))
+	return options
+}
+
 func validateServiceConcurrencyLimit(r *test.KnRunResultCollector, serviceName, concurrencyLimit string) {
 	jsonpath := "jsonpath={.items[0].spec.template.spec.containerConcurrency}"
 	out := r.KnTest().Kn().Run("service", "list", serviceName, "-o", jsonpath)
@@ -190,6 +242,13 @@ func validateServiceMaxScale(r *test.KnRunResultCollector, serviceName, maxScale
 	r.AssertNoError(out)
 }
 
+func validateServiceInitScale(r *test.KnRunResultCollector, serviceName, initScale string) {
+	jsonpath := "jsonpath={.items[0].spec.template.metadata.annotations.autoscaling\\.knative\\.dev/initialScale}"
+	out := r.KnTest().Kn().Run("service", "list", serviceName, "-o", jsonpath)
+	assert.Equal(r.T(), out.Stdout, initScale)
+	r.AssertNoError(out)
+}
+
 func validateServiceAnnotations(r *test.KnRunResultCollector, serviceName string, annotations map[string]string) {
 	metadataAnnotationsJsonpathFormat := "jsonpath={.metadata.annotations.%s}"
 	templateAnnotationsJsonpathFormat := "jsonpath={.spec.template.metadata.annotations.%s}"
@@ -205,6 +264,26 @@ func validateServiceAnnotations(r *test.KnRunResultCollector, serviceName string
 	}
 }
 
+func validateServiceAndRevisionAnnotations(r *test.KnRunResultCollector, serviceName string, expectedServiceAnnotations, expectedRevisionAnnotations map[string]string) {
+
+	metadataAnnotationsJsonpathFormat := "jsonpath={.metadata.annotations.%s}"
+	templateAnnotationsJsonpathFormat := "jsonpath={.spec.template.metadata.annotations.%s}"
+
+	for k, v := range expectedServiceAnnotations {
+
+		out := r.KnTest().Kn().Run("service", "describe", serviceName, "-o", fmt.Sprintf(metadataAnnotationsJsonpathFormat, k))
+		assert.Equal(r.T(), v, out.Stdout)
+		r.AssertNoError(out)
+	}
+
+	for k, v := range expectedRevisionAnnotations {
+
+		out := r.KnTest().Kn().Run("service", "describe", serviceName, "-o", fmt.Sprintf(templateAnnotationsJsonpathFormat, k))
+		assert.Equal(r.T(), v, out.Stdout)
+		r.AssertNoError(out)
+	}
+}
+
 func validateLabels(r *test.KnRunResultCollector, serviceName string, expectedServiceLabels, expectedRevisionLabels map[string]string) {
 	out := r.KnTest().Kn().Run("service", "describe", serviceName, "-ojson")
 	data := json.NewDecoder(strings.NewReader(out.Stdout))
@@ -227,11 +306,12 @@ func validateContainerField(r *test.KnRunResultCollector, serviceName, field, ex
 }
 
 func validateUserID(r *test.KnRunResultCollector, serviceName string, uid int64) {
-	out := r.KnTest().Kn().Run("service", "describe", serviceName, "-ojson")
-	data := json.NewDecoder(strings.NewReader(out.Stdout))
-	data.UseNumber()
-	var service servingv1.Service
-	err := data.Decode(&service)
-	assert.NilError(r.T(), err)
-	assert.Equal(r.T(), *service.Spec.Template.Spec.Containers[0].SecurityContext.RunAsUser, uid)
+	svc := test.GetServiceFromKNServiceDescribe(r, serviceName)
+	assert.Equal(r.T(), *svc.Spec.Template.Spec.Containers[0].SecurityContext.RunAsUser, uid)
+}
+
+func validatePort(r *test.KnRunResultCollector, serviceName string, portNumber int32, portName string) {
+	svc := test.GetServiceFromKNServiceDescribe(r, serviceName)
+	assert.Equal(r.T(), svc.Spec.Template.Spec.Containers[0].Ports[0].ContainerPort, portNumber)
+	assert.Equal(r.T(), svc.Spec.Template.Spec.Containers[0].Ports[0].Name, portName)
 }
